@@ -1,6 +1,6 @@
 # This file is part of hvsrpy a Python package for horizontal-to-vertical
 # spectral ratio processing.
-# Copyright (C) 2019-2020 Joseph P. Vantassel (jvantassel@utexas.edu)
+# Copyright (C) 2019-2021 Joseph P. Vantassel (jvantassel@utexas.edu)
 #
 #     This program is free software: you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -17,9 +17,13 @@
 
 """Import modules into the hvsrpy namespace."""
 
-__version__ = "0.4.2"
+import logging
+
+from .meta import __version__
 from .hvsr import Hvsr
 from .hvsr_rotated import HvsrRotated
 from .sensor3c import Sensor3c
 from .plottools import quick_plot
 from .hvsr_spatial import HvsrVault, montecarlo_f0
+
+logging.getLogger('swprocess').addHandler(logging.NullHandler())
\ No newline at end of file
