@@ -1,6 +1,6 @@
 # This file is part of hvsrpy, a Python package for horizontal-to-vertical
 # spectral ratio processing.
-# Copyright (C) 2019-2020 Joseph P. Vantassel (jvantassel@utexas.edu)
+# Copyright (C) 2019-2021 Joseph P. Vantassel (jvantassel@utexas.edu)
 #
 #     This program is free software: you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -18,17 +18,15 @@
 """Class definition for Sensor3c, a 3-component sensor."""
 
 import math
-import logging
 import json
 import warnings
 
 import numpy as np
 import obspy
-from sigpropy import TimeSeries, FourierTransform, WindowedTimeSeries, FourierTransformSuite
+from sigpropy import TimeSeries, FourierTransform
 
 from hvsrpy import Hvsr, HvsrRotated
 
-logger = logging.getLogger(__name__)
 
 __all__ = ["Sensor3c"]
 
@@ -52,52 +50,53 @@ class Sensor3c():
         """Perform checks on inputs.
 
         Specifically:
+
         1. Ensure all components are `TimeSeries` objects.
         2. Ensure all components have equal `dt`.
-        3. Ensure all components have same `nsamples`. If not trim
-        components to the common length.
+        3. Ensure all components have same `nsamples`, if not trim.
 
         Parameters
         ----------
         values_dict : dict
-            Key is human readable component name {'ns', 'ew', 'vt'}.
+            Key is human-readable component name {'ns', 'ew', 'vt'}.
             Value is corresponding `TimeSeries` object.
 
         Returns
         -------
         Tuple
-            Containing checked components.
+            Containing checked components as tuple of the form
+            `(ns, ew, vt)`.
 
         """
         ns = values_dict["ns"]
-        if not isinstance(ns, TimeSeries):
+        try:
+            ns = TimeSeries.from_timeseries(ns)
+        except AttributeError as e:
             msg = f"'ns' must be a `TimeSeries`, not {type(ns)}."
-            raise TypeError(msg)
+            raise TypeError(msg) from e
+        values_dict["ns"] = ns
+
         dt = ns.dt
         nsamples = ns.nsamples
-        flag_cut = False
         for key, value in values_dict.items():
             if key == "ns":
                 continue
+
             if not isinstance(value, TimeSeries):
                 msg = f"`{key}`` must be a `TimeSeries`, not {type(value)}."
                 raise TypeError(msg)
+            else:
+                values_dict[key] = TimeSeries.from_timeseries(value)
+
             if value.dt != dt:
                 msg = "All components must have equal `dt`."
                 raise ValueError(msg)
-            if value.nsamples != nsamples:
-                logging.info("Components are not of the same length.")
-                flag_cut = True
 
-        if flag_cut:
-            min_time = 0
-            max_time = np.inf
-            for value in values_dict.values():
-                min_time = max(min_time, min(value.time))
-                max_time = min(max_time, max(value.time))
-            logging.info(f"Trimming between {min_time} and {max_time}.")
-            for value in values_dict.values():
-                value.trim(min_time, max_time)
+            if value.nsamples != nsamples:
+                txt = "".join([f"{_k}={_v.nsamples} " for _k,
+                               _v in values_dict.items()])
+                msg = f"Components are different length: {txt}"
+                raise ValueError(msg)
 
         return (values_dict["ns"], values_dict["ew"], values_dict["vt"])
 
@@ -109,7 +108,7 @@ class Sensor3c():
         ns, ew, vt : TimeSeries
             `TimeSeries` object for each component.
         meta : dict, optional
-            Meta information for object, default is None.
+            Meta information for object, default is `None`.
 
         Returns
         -------
@@ -117,23 +116,15 @@ class Sensor3c():
             Initialized 3-component sensor object.
 
         """
-        self.ns, self.ew, self.vt = self._check_input({"ns": ns,
-                                                       "ew": ew,
-                                                       "vt": vt})
-        self.meta = {} if meta is None else meta
+        values_dict = {"ns": ns, "ew": ew, "vt": vt}
+        self.ns, self.ew, self.vt = self._check_input(values_dict)
 
-    @property
-    def normalization_factor(self):
-        """Time history normalization factor across all components."""
-        factor = 1E-6
-        for attr in ["ns", "ew", "vt"]:
-            cmax = np.max(np.abs(getattr(self, attr).amp.flatten()))
-            factor = cmax if cmax > factor else factor
-        return factor
+        meta = {} if meta is None else meta
+        self.meta = {"File Name": "NA", **meta}
 
     @classmethod
     def from_mseed(cls, fname=None, fnames_1c=None):
-        """Create 3-component sensor (Sensor3c) object from .mseed file.
+        """Create from .mseed file(s).
 
         Parameters
         ----------
@@ -161,10 +152,11 @@ class Sensor3c():
             If both `fname` and `fname_verbose` are `None`.
 
         """
-        if fnames_1c is None and fname is None:
-            msg = "`fnames_1c` and `fname` cannot both be `None`."
-            raise ValueError(msg)
-        if fnames_1c is not None:
+        # One miniSEED file is provided, which contains all three components.
+        if fname is not None and fnames_1c is None:
+            traces = obspy.read(fname, format="MSEED")
+        # Three miniSEED files are provided, one per component.
+        elif fnames_1c is not None and fname is None:
             trace_list = []
             for key in ["e", "n", "z"]:
                 stream = obspy.read(fnames_1c[key], format="MSEED")
@@ -184,11 +176,14 @@ class Sensor3c():
                         key.capitalize()
                 trace_list.append(trace)
             traces = obspy.Stream(trace_list)
+            fname = fnames_1c["n"]
+        # Both or neither miniSEED file option is provided.
         else:
-            traces = obspy.read(fname, format="MSEED")
+            msg = "`fnames_1c` and `fname` cannot both be defined or both be `None`."
+            raise ValueError(msg)
 
         if len(traces) != 3:
-            msg = f"miniseed file {fname} has {len(traces)} traces, but should have 3."
+            msg = f"Provided {len(traces)} traces, but must only provide 3."
             raise ValueError(msg)
 
         found_ew, found_ns, found_vt = False, False, False
@@ -203,28 +198,12 @@ class Sensor3c():
                 vt = TimeSeries.from_trace(trace)
                 found_vt = True
             else:
-                msg = "Missing, duplicate, or incorrectly named components. See documentation."
+                msg = "Missing, duplicate, or incorrectly named components."
                 raise ValueError(msg)
 
         meta = {"File Name": fname}
         return cls(ns, ew, vt, meta)
 
-    def to_dict(self):
-        """Dictionary representation of `Sensor3c` object.
-
-        Returns
-        -------
-        dict
-            With all of the components of the `Sensor3c`.
-
-        """
-        dictionary = {}
-        for name in ["ns", "ew", "vt"]:
-            value = getattr(self, name).to_dict()
-            dictionary[name] = value
-        dictionary["meta"] = self.meta
-        return dictionary
-
     @classmethod
     def from_dict(cls, dictionary):
         """Create `Sensor3c` object from dictionary representation.
@@ -249,18 +228,6 @@ class Sensor3c():
             components.append(TimeSeries.from_dict(dictionary[comp]))
         return cls(*components, meta=dictionary.get("meta"))
 
-    def to_json(self):
-        """Json string representation of `Sensor3c` object.
-
-        Returns
-        -------
-        str
-            With all of the components of the `Sensor3c`.
-
-        """
-        dictionary = self.to_dict()
-        return json.dumps(dictionary)
-
     @classmethod
     def from_json(cls, json_str):
         """Create `Sensor3c` object from Json-string representation.
@@ -284,8 +251,17 @@ class Sensor3c():
         dictionary = json.loads(json_str)
         return cls.from_dict(dictionary)
 
+    @property
+    def normalization_factor(self):
+        """Time history normalization factor across all components."""
+        factor = 0
+        for attr in ["ns", "ew", "vt"]:
+            cmax = np.max(np.abs(getattr(self, attr).amplitude))
+            factor = cmax if cmax > factor else factor
+        return factor
+
     def split(self, windowlength):
-        """Split component `TimeSeries` into `WindowedTimeSeries`.
+        """Split component `TimeSeries`.
 
         Refer to
         `SigProPy <https://sigpropy.readthedocs.io/en/latest/?badge=latest>`_
@@ -293,9 +269,7 @@ class Sensor3c():
 
         """
         for attr in ["ew", "ns", "vt"]:
-            wtseries = WindowedTimeSeries.from_timeseries(getattr(self, attr),
-                                                          windowlength)
-            setattr(self, attr, wtseries)
+            getattr(self, attr).split(windowlength)
 
     def detrend(self):
         """Detrend components.
@@ -308,7 +282,7 @@ class Sensor3c():
         for comp in [self.ew, self.ns, self.vt]:
             comp.detrend()
 
-    def bandpassfilter(self, flow, fhigh, order):  # pragma: no cover
+    def bandpassfilter(self, flow, fhigh, order):
         """Bandpassfilter components.
 
         Refer to
@@ -343,56 +317,27 @@ class Sensor3c():
         ffts = {}
         for attr in ["ew", "ns", "vt"]:
             tseries = getattr(self, attr)
-            if isinstance(tseries, WindowedTimeSeries):
-                fft = FourierTransformSuite.from_timeseries(tseries, **kwargs)
-            elif isinstance(tseries, TimeSeries):
-                fft = FourierTransform.from_timeseries(tseries, **kwargs)
-            else:
-                raise NotImplementedError
+            fft = FourierTransform.from_timeseries(tseries, **kwargs)
             ffts[attr] = fft
         return ffts
 
-    def combine_horizontals(self, method, horizontals, azimuth=None):
-        """Combine two horizontal components (`ns` and `ew`).
+    @staticmethod
+    def _combine_horizontal_fd(method, ns, ew):
+        """Combine horizontal components in the frequency domain.
 
         Parameters
         ----------
-        method : {'squared-average', 'geometric-mean', 'single-azimuth', 'multiple-azimuths'}
-            Defines how the two horizontal components are combined
-            to represent a single horizontal component.
-        horizontals : dict
-            If combination is done in the frequency-domain (i.e.,
-            `method in ['squared-average', 'geometric-mean']`)
-            horizontals is a `dict` of `FourierTransform` objects,
-            see :meth:`transform <Sensor3c.transform>` for details. If
-            combination is done in the time-domain
-            (i.e., `method in ['single-azimuth', 'multiple-azimuths']`)
-            horizontals is a `dict` of `TimeSeries` objects.
-        azimuth : float, optional
-            Valid only if `method` is `single-azimuth` in which case an
-            azimuth (clockwise positive) from North (i.e., 0 degrees) is
-            required.
+        method : {'squared-average', 'geometric-mean'}
+            Defines how the two horizontal components are combined.
+        ns, ew : FourierTransform
+            Frequency domain representation of each component.
 
         Returns
         -------
-        TimeSeries or FourierTransform
-            Depending upon the specified `method` requires the
-            combination to happen in the time or frequency domain.
+        FourierTransform
+            Representing the combined horizontal components.
 
         """
-        if method in ["squared-average", "geometric-mean"]:
-            return self._combine_horizontal_fd(method, horizontals)
-        elif method in ["azimuth", "single-azimuth"]:
-            return self._combine_horizontal_td(method, horizontals, azimuth=azimuth)
-        else:
-            msg = f"`method`={method} has not been implemented."
-            raise NotImplementedError(msg)
-
-    @staticmethod
-    def _combine_horizontal_fd(method, horizontals, **kwargs):
-        ns = horizontals["ns"]
-        ew = horizontals["ew"]
-
         if method == "squared-average":
             horizontal = np.sqrt((ns.mag*ns.mag + ew.mag*ew.mag)/2)
         elif method == "geometric-mean":
@@ -401,33 +346,33 @@ class Sensor3c():
             msg = f"`method`={method} has not been implemented."
             raise NotImplementedError(msg)
 
-        if isinstance(ns, FourierTransformSuite):
-            return FourierTransformSuite(horizontal, ns.frq)
-        elif isinstance(ns, FourierTransform):
-            return FourierTransform(horizontal, ns.frq)
-        else:
-            raise NotImplementedError
+        return FourierTransform(horizontal, ns.frequency, dtype=float)
 
-    def _combine_horizontal_td(self, method, horizontals, azimuth):
+    def _combine_horizontal_td(self, method, azimuth):
+        """Combine horizontal components in the time domain.
+
+        azimuth : float, optional
+            Azimuth (clockwise positive) from North (i.e., 0 degrees).
+
+        Returns
+        -------
+        TimeSeries
+            Representing the combined horizontal components.
+
+        """
         az_rad = math.radians(azimuth)
-        ns = horizontals["ns"]
-        ew = horizontals["ew"]
 
         if method in ["azimuth", "single-azimuth"]:
-            horizontal = ns.amp*math.cos(az_rad) + ew.amp*math.sin(az_rad)
+            horizontal = self.ns._amp * \
+                math.cos(az_rad) + self.ew._amp*math.sin(az_rad)
         else:
             msg = f"method={method} has not been implemented."
             raise NotImplementedError(msg)
 
-        if isinstance(ns, WindowedTimeSeries):
-            return WindowedTimeSeries(horizontal, ns.dt)
-        elif isinstance(ns, TimeSeries):
-            return TimeSeries(horizontal, ns.dt)
-        else:
-            raise NotImplementedError
+        return TimeSeries(horizontal, self.ns.dt)
 
     def hv(self, windowlength, bp_filter, taper_width, bandwidth,
-           resampling, method, azimuth=None):
+           resampling, method, f_low=None, f_high=None, azimuth=None):
         """Prepare time series and Fourier transforms then compute H/V.
 
         Parameters
@@ -445,9 +390,13 @@ class Sensor3c():
         resampling : dict
             Resampling settings, of the form
             `{'minf':float, 'maxf':float, 'nf':int, 'res_type':str}`.
-        method : {'squared-averge', 'geometric-mean', 'single-azimuth', 'multiple-azimuths'}
+        method : {'squared-average', 'geometric-mean', 'single-azimuth', 'multiple-azimuths'}
             Refer to :meth:`combine_horizontals <Sensor3c.combine_horizontals>`
             for details.
+        f_low, f_high : float, optional
+            Upper and lower frequency limits to restrict peak selection,
+            default is `None` meaning search range will not be
+            restricted.
         azimuth : float, optional
             Refer to
             :meth:`combine_horizontals <Sensor3c.combine_horizontals>`
@@ -459,32 +408,49 @@ class Sensor3c():
             Instantiated `Hvsr` object.
 
         """
+        # Bandpass filter raw signal.
         if bp_filter["flag"]:
-            self.bandpassfilter(flow=bp_filter["flow"],
-                                fhigh=bp_filter["fhigh"],
-                                order=bp_filter["order"])
+            self.bandpassfilter(bp_filter["flow"],
+                                bp_filter["fhigh"],
+                                bp_filter["order"])
+
+        # Split each time record into windows of length windowlength.
         self.split(windowlength)
+
+        # Detrend each window individually.
         self.detrend()
+
+        # Cosine taper each window individually.
         self.cosine_taper(width=taper_width)
 
+        # Combine horizontal components directly.
         if method in ["squared-average", "geometric-mean", "azimuth", "single-azimuth"]:
+
+            # Deprecate `azimuth` in favor of the more descriptive `single-azimuth`.
             if method == "azimuth":
                 msg = "method='azimuth' is deprecated, replace with the more descriptive 'single-azimuth'."
                 warnings.warn(msg, DeprecationWarning)
                 method = "single-azimuth"
-            return self._make_hvsr(method=method, resampling=resampling,
-                                   bandwidth=bandwidth, azimuth=azimuth)
 
+            return self._make_hvsr(method=method, resampling=resampling,
+                                   bandwidth=bandwidth, f_low=f_low,
+                                   f_high=f_high, azimuth=azimuth)
+
+        # Rotate horizontal components through a variety of azimuths.
         elif method in ["rotate", "multiple-azimuths"]:
+
+            # Deprecate `rotate` in favor of the more descriptive `multiple-azimuths`.
             if method == "rotate":
                 msg = "method='rotate' is deprecated, replace with the more descriptive 'multiple-azimuths'."
                 warnings.warn(msg, DeprecationWarning)
-                method = "multiple-azimuths"
+
             hvsrs = np.empty(len(azimuth), dtype=object)
             for index, az in enumerate(azimuth):
                 hvsrs[index] = self._make_hvsr(method="single-azimuth",
                                                resampling=resampling,
                                                bandwidth=bandwidth,
+                                               f_low=f_low,
+                                               f_high=f_high,
                                                azimuth=az)
             return HvsrRotated.from_iter(hvsrs, azimuth, meta=self.meta)
 
@@ -492,25 +458,18 @@ class Sensor3c():
             msg = f"`method`={method} has not been implemented."
             raise NotImplementedError(msg)
 
-    def _make_hvsr(self, method, resampling, bandwidth, azimuth=None):
+    def _make_hvsr(self, method, resampling, bandwidth, f_low=None, f_high=None, azimuth=None):
         if method in ["squared-average", "geometric-mean"]:
             ffts = self.transform()
-            hor = self.combine_horizontals(method=method, horizontals=ffts)
+            hor = self._combine_horizontal_fd(
+                method=method, ew=ffts["ew"], ns=ffts["ns"])
             ver = ffts["vt"]
             del ffts
         elif method == "single-azimuth":
-            hor = self.combine_horizontals(method=method,
-                                           horizontals={"ew": self.ew,
-                                                        "ns": self.ns},
-                                           azimuth=azimuth)
-            if isinstance(hor, WindowedTimeSeries):
-                hor = FourierTransformSuite.from_timeseries(hor)
-                ver = FourierTransformSuite.from_timeseries(self.vt)
-            elif isinstance(hor, TimeSeries):
-                hor = FourierTransform.from_timeseries(hor)
-                ver = FourierTransform.from_timeseries(self.vt)
-            else:
-                raise NotImplementedError
+            hor = self._combine_horizontal_td(method=method,
+                                              azimuth=azimuth)
+            hor = FourierTransform.from_timeseries(hor)
+            ver = FourierTransform.from_timeseries(self.vt)
         else:
             msg = f"`method`={method} has not been implemented."
             raise NotImplementedError(msg)
@@ -527,22 +486,52 @@ class Sensor3c():
                                resampling["maxf"],
                                resampling["nf"])
         else:
-            raise NotImplementedError
+            msg = f"`res_type`={resampling['res_type']} has not been implemented."
+            raise NotImplementedError(msg)
 
         hor.smooth_konno_ohmachi_fast(frq, bandwidth)
         ver.smooth_konno_ohmachi_fast(frq, bandwidth)
-        hor.amp /= ver.amp
+        hor._amp /= ver._amp
         hvsr = hor
         del ver
 
-        if self.ns.n_windows == 1:
+        if self.ns.nseries == 1:
             window_length = max(self.ns.time)
         else:
             window_length = max(self.ns.time[0])
 
         self.meta["Window Length"] = window_length
 
-        return Hvsr(hvsr.amp, hvsr.frq, find_peaks=False, meta=self.meta)
+        return Hvsr(hvsr.amplitude, hvsr.frequency, find_peaks=False,
+                    f_low=f_low, f_high=f_high, meta=self.meta)
+
+    def to_dict(self):
+        """`Sensor3c` object as `dict`.
+
+        Returns
+        -------
+        dict
+            Dictionary representation of a `Sensor3c`.
+
+        """
+        dictionary = {}
+        for name in ["ns", "ew", "vt"]:
+            value = getattr(self, name).to_dict()
+            dictionary[name] = value
+        dictionary["meta"] = self.meta
+        return dictionary
+
+    def to_json(self):
+        """`Sensor3c` object as JSON-string.
+
+        Returns
+        -------
+        str
+            JSON-string representation of `Sensor3c`.
+
+        """
+        dictionary = self.to_dict()
+        return json.dumps(dictionary)
 
     def __iter__(self):
         """Iterable representation of a Sensor3c object."""
@@ -550,7 +539,7 @@ class Sensor3c():
 
     def __str__(self):
         """Human-readable representation of `Sensor3c` object."""
-        return "Sensor3c"
+        return f"Sensor3c at {id(self)}"
 
     def __repr__(self):
         """Unambiguous representation of `Sensor3c` object."""
