@@ -1,6 +1,6 @@
 # This file is part of hvsrpy, a Python package for
 # horizontal-to-vertical spectral ratio processing.
-# Copyright (C) 2019-2020 Joseph P. Vantassel (jvantassel@utexas.edu)
+# Copyright (C) 2019-2021 Joseph P. Vantassel (jvantassel@utexas.edu)
 #
 #     This program is free software: you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -204,12 +204,12 @@ class Test_Utils(TestCase):
                      ([1, 1, 1], [1, 1, 1, 1, 1, 1])]
 
         for count, expected_tuple in enumerate(expecteds):
-            fname = self.full_path + f"data/utils/ex{count}.hv"
+            fname = self.full_path + f"../other/ex{count}.hv"
             with open(os.devnull, "w") as sys.stdout:
                 returned_tuple = load(fname)
                 sys.stdout = sys.__stdout__
             for expected, returned in zip(expected_tuple, returned_tuple):
-                expected = np.array(expected)
+                expected = np.array(expected, dtype=np.double)
                 self.assertArrayEqual(expected, returned)
 
     def test_parse_hvsrpy_output(self):
@@ -228,7 +228,7 @@ class Test_Utils(TestCase):
                     raise ValueError
 
         # Ex 0
-        fname = self.full_path + "data/utils/ex0.hv"
+        fname = self.full_path + "../other/ex0.hv"
         expected = {"windowlength": 60.0,
                     "total_windows": 30,
                     "rejection_bool": True,
@@ -237,7 +237,7 @@ class Test_Utils(TestCase):
                     "distribution_f0": "normal",
                     "mean_f0": 0.6976,
                     "std_f0": 0.1353,
-                    "distribution_mc": "log-normal",
+                    "distribution_mc": "lognormal",
                     "f0_mc": 0.7116,
                     "amplitude_f0_mc": 3.8472,
                     }
@@ -249,7 +249,7 @@ class Test_Utils(TestCase):
         compare_data_dict(expected, returned)
 
         # Ex 1
-        fname = self.full_path + "data/utils/ex1.hv"
+        fname = self.full_path + "../other/ex1.hv"
         expected = {"windowlength": 60.0,
                     "total_windows": 60,
                     "rejection_bool": True,
@@ -258,7 +258,7 @@ class Test_Utils(TestCase):
                     "distribution_f0": "normal",
                     "mean_f0": 0.7155,
                     "std_f0": 0.0759,
-                    "distribution_mc": "log-normal",
+                    "distribution_mc": "lognormal",
                     "f0_mc": 0.7378,
                     "amplitude_f0_mc": 3.9661,
                     }
@@ -270,7 +270,7 @@ class Test_Utils(TestCase):
         compare_data_dict(expected, returned)
 
         # Ex 2
-        fname = self.full_path + "data/utils/ex2.hv"
+        fname = self.full_path + "../other/ex2.hv"
         expected = {"windowlength": 60.0,
                     "total_windows": 30,
                     "rejection_bool": True,
@@ -279,7 +279,7 @@ class Test_Utils(TestCase):
                     "distribution_f0": "normal",
                     "mean_f0": 0.7035,
                     "std_f0": 0.1391,
-                    "distribution_mc": "log-normal",
+                    "distribution_mc": "lognormal",
                     "f0_mc": 0.7116,
                     "amplitude_f0_mc": 3.9097,
                     }
@@ -291,7 +291,7 @@ class Test_Utils(TestCase):
         compare_data_dict(expected, returned)
 
         # Ex 3
-        fname = self.full_path + "data/utils/ex3.hv"
+        fname = self.full_path + "../other/ex3.hv"
         expected = {"windowlength": 60.0,
                     "total_windows": 60,
                     "rejection_bool": True,
@@ -300,7 +300,7 @@ class Test_Utils(TestCase):
                     "distribution_f0": "normal",
                     "mean_f0": 0.7994,
                     "std_f0": 0.0365,
-                    "distribution_mc": "log-normal",
+                    "distribution_mc": "lognormal",
                     "f0_mc": 0.7933,
                     "amplitude_f0_mc": 4.8444,
                     }
@@ -311,6 +311,45 @@ class Test_Utils(TestCase):
         returned = utils.parse_hvsrpy_output(fname)
         compare_data_dict(expected, returned)
 
+# import swprocess
+# import json
+# from testtools import unittest, TestCase, get_full_path
+# import logging
+# logging.basicConfig(level=logging.CRITICAL)
+
+
+# class Test_Hvsr(TestCase):
+
+#     def setUp(self):
+#         self.fpath = get_full_path(__file__)
+
+#     def test_from_geopsy_file(self):
+#         fname = self.fpath + "data/mm/test_ZM_STN01.hv"
+#         test = swprocess.Hvsr.from_geopsy_file(fname=fname,
+#                                                            identifier="TaDa")
+#         frq = [[0.1, 0.101224, 0.102462, 50]]
+#         amp = [[4.26219, 4.24461, 4.20394, 0.723993]]
+#         idn = "TaDa"
+
+#         self.assertListEqual(test.frq, frq)
+#         self.assertListEqual(test.amp, amp)
+#         self.assertTrue(test.idn, idn)
+
+#     def test_from_geopsy_folder(self):
+#         dirname = self.fpath + "data/mm/test_dir"
+#         hv = swprocess.Hvsr.from_geopsy_folder(dirname=dirname,
+#                                                            identifier="TADA")
+#         with open(self.fpath + "data/mm/test_dir_data.json", "r") as f:
+#             known = json.load(f)
+
+#         for test_frq, test_amp, known in zip(hv.frq, hv.amp, known):
+#             self.assertListEqual(test_frq, known["frequency"])
+#             self.assertListEqual(test_amp, known["amplitude"])
+
+
+# if __name__ == "__main__":
+#     unittest.main()
+
 
 if __name__ == "__main__":
     unittest.main()
