@@ -1,6 +1,6 @@
 # This file is part of hvsrpy, a Python package for
 # horizontal-to-vertical spectral ratio processing.
-# Copyright (C) 2019-2020 Joseph P. Vantassel (jvantassel@utexas.edu)
+# Copyright (C) 2019-2021 Joseph P. Vantassel (jvantassel@utexas.edu)
 #
 #     This program is free software: you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -19,6 +19,8 @@
 
 import unittest
 
+import numpy as np
+
 def get_full_path(path):
     if path.count("/") > 1:
         file_name = path.split(r"/")[-1]
@@ -34,13 +36,33 @@ class TestCase(unittest.TestCase):
         for a, b in zip(list1, list2):
             self.assertAlmostEqual(a, b, **kwargs)
 
+    def assertNestedListEqual(self, list1, list2, **kwargs):
+        if len(list1) != len(list2):
+            msg = f"\nExpected:\n{list1}\nReturned:\n{list2})"
+            raise AssertionError(msg)
+
+        for l1, l2 in zip(list1, list2):
+                self.assertListEqual(l1, l2, **kwargs)
+
     def assertArrayEqual(self, array1, array2):
-        self.assertListEqual(array1.tolist(), array2.tolist())
+        try:
+            self.assertTrue(np.equal(array1, array2, casting='no').all())
+        except AssertionError as e:
+            msg = f"\nExpected:\n{array1}\nReturned:\n{array2})"
+            raise AssertionError(msg) from e
 
     def assertArrayAlmostEqual(self, array1, array2, **kwargs):
-        if array1.size != array2.size:
-            self.assertEqual(array1.size, array2.size)
-        array1 = array1.flatten()
-        array2 = array2.flatten()
-        for v1, v2 in zip(array1, array2):
-            self.assertAlmostEqual(v1, v2, **kwargs)
+        if kwargs.get("places", False):
+            kwargs["atol"] = 1/(10**kwargs["places"])
+            del kwargs["places"]
+
+        if kwargs.get("delta", False):
+            kwargs["atol"] = kwargs["delta"]
+            del kwargs["delta"]
+
+        try:
+            self.assertTrue(np.allclose(array1, array2, **kwargs))
+        except AssertionError as e:
+            msg = f"\nExpected:\n{array1}\nReturned:\n{array2})"
+            raise AssertionError(msg) from e
+        
\ No newline at end of file
